window.Gleam.initSearch([{"doc":"gleatfy","title":"gleatfy","content":"# gleatfy\n\n[![Package Version](https://img.shields.io/hexpm/v/gleatfy)](https://hex.pm/packages/gleatfy)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleatfy/)\n\n```sh\ngleam add gleatfy@1\n```\n```gleam\nimport gleam/hackney\nimport gleatfy.{\n  High, Markdown, View, actions, message, priority, send, tags, title, topic,\n}\n\npub fn main() {\n  gleatfy.new()\n  |&gt; topic(is: &quot;gleatfy_test_topic&quot;)\n  |&gt; priority(is: High)\n  |&gt; message(is: Markdown(\n    &quot;[**gleatfy**](https://github.com/l-x/gleatfy) is a [Gleam](https://gleam.run) client for the [ntfy](https://ntfy.sh) push notification API&quot;,\n  ))\n  |&gt; title(is: &quot;Aufgemerkt!&quot;)\n  |&gt; tags(are: [&quot;warning&quot;, &quot;important&quot;])\n  |&gt; actions(are: [\n    View(&quot;View on GitHub&quot;, &quot;https://github.com/l-x/gleatfy&quot;, clear_after: True),\n    View(&quot;Visit ntfy.sh&quot;, &quot;https://ntfy.sh&quot;, clear_after: False),\n    View(&quot;Visit gleam.run&quot;, &quot;https://gleam.run&quot;, clear_after: False),\n  ])\n  |&gt; send(using: hackney.send)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gleatfy&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"gleatfy","title":"Action","content":"pub type Action {\n  View(label: String, url: String, clear_after: Bool)\n  Http(\n    label: String,\n    request: Request(String),\n    clear_after: Bool,\n  )\n  Broadcast(\n    label: String,\n    intent: String,\n    extras: List(#(String, String)),\n    clear_after: Bool,\n  )\n}\n Defintion for action buttons. If `clear_after` is set to `True`\n the message is marked as read after clicking on this button.\n See https://docs.ntfy.sh/publish/#action-buttons\n \nView(label: String, url: String, clear_after: Bool)\n\n\nHttp(label: String, request: Request(String), clear_after: Bool)\n\n\nBroadcast(\n  label: String,\n  intent: String,\n  extras: List(#(String, String)),\n  clear_after: Bool,\n)\n\n\nSynonyms:\ngleatfy.Action\ngleatfy Action","url":"gleatfy.html#Action"},{"doc":"gleatfy","title":"Builder","content":"pub opaque type Builder\n\n\nSynonyms:\ngleatfy.Builder\ngleatfy Builder","url":"gleatfy.html#Builder"},{"doc":"gleatfy","title":"Error","content":"pub type Error(a) {\n  InvalidServerUrl(String)\n  InvalidTopic(String)\n  ClientError(a)\n  InvalidServerResponse(String)\n  ServerError(code: Int, http_status: Int, message: String)\n}\n\nInvalidServerUrl(String)\n\n\nInvalidTopic(String)\n\n\nClientError(a)\n\n\nInvalidServerResponse(String)\n\n\nServerError(code: Int, http_status: Int, message: String)\n\n\nSynonyms:\ngleatfy.Error\ngleatfy Error","url":"gleatfy.html#Error"},{"doc":"gleatfy","title":"Login","content":"pub type Login {\n  Basic(user: String, password: String)\n  Token(token: String)\n}\n Authentication method to use\n See https://docs.ntfy.sh/publish/#authentication\n \nBasic(user: String, password: String)\n\n\nToken(token: String)\n\n\nSynonyms:\ngleatfy.Login\ngleatfy Login","url":"gleatfy.html#Login"},{"doc":"gleatfy","title":"Message","content":"pub type Message {\n  Text(String)\n  Markdown(String)\n}\n Notification message to send\n \nText(String)\n\n\nMarkdown(String)\n\n\nSynonyms:\ngleatfy.Message\ngleatfy Message","url":"gleatfy.html#Message"},{"doc":"gleatfy","title":"Priority","content":"pub type Priority {\n  VeryHigh\n  High\n  Normal\n  Low\n  VeryLow\n}\n\nVeryHigh\n\n\nHigh\n\n\nNormal\n\n\nLow\n\n\nVeryLow\n\n\nSynonyms:\ngleatfy.Priority\ngleatfy Priority","url":"gleatfy.html#Priority"},{"doc":"gleatfy","title":"actions","content":"pub fn actions(\n  builder: Builder,\n  are actions: List(Action),\n) -&gt; Builder\n Add a list of action buttons for the notification\n See https://docs.ntfy.sh/publish/#action-buttons\n \n ## Examples\n \n \n new() |&gt; actions(are: [View(&quot;Visit ntfy.sh&quot;, &quot;https://ntfy.sh&quot;, True)])\n \n \n \n   new()\n |&gt; actions(are: [\n   Broadcast(\n    &quot;Take picture&quot;,\n     &quot;io.heckel.ntfy.USER_ACTION&quot;,\n     [#(&quot;cmd&quot;, &quot;pic&quot;), #(&quot;camera&quot;, &quot;front&quot;)],\n    False,\n  ),\n ])\n \n \n \n   new()\n   |&gt; actions(are: [\n     Http(\n       &quot;Close door&quot;,\n       {\n         let assert Ok(req) = request.to(&quot;https://api.mygarage.lan/&quot;)\n \n         req\n         |&gt; request.set_method(http.Put)\n         |&gt; request.set_header(&quot;Authorization&quot;, &quot;Bearer zAzsx1sk..&quot;)\n         |&gt; request.set_body(&quot;{\\&quot;action\\&quot;: \\&quot;close\\&quot;}&quot;)\n       },\n       True,\n     ),\n   ])\n }\n \n \nSynonyms:\ngleatfy.actions\ngleatfy actions","url":"gleatfy.html#actions"},{"doc":"gleatfy","title":"attachment_filename","content":"pub fn attachment_filename(\n  builder: Builder,\n  is filename: String,\n) -&gt; Builder\n Set a specific name for an attached file\n See https://docs.ntfy.sh/publish/#attach-file-from-a-url\n \nSynonyms:\ngleatfy.attachment_filename\ngleatfy attachment_filename","url":"gleatfy.html#attachment_filename"},{"doc":"gleatfy","title":"attachment_url","content":"pub fn attachment_url(\n  builder: Builder,\n  is attachment_url: String,\n) -&gt; Builder\n Attach a file by a given URL\n See https://docs.ntfy.sh/publish/#attach-file-from-a-url\n \nSynonyms:\ngleatfy.attachment_url\ngleatfy attachment_url","url":"gleatfy.html#attachment_url"},{"doc":"gleatfy","title":"call","content":"pub fn call(builder: Builder, to number: String) -&gt; Builder\n Set a phone number to be called to read the message out loud using text-to-speech\n See https://docs.ntfy.sh/publish/#phone-calls\n \nSynonyms:\ngleatfy.call\ngleatfy call","url":"gleatfy.html#call"},{"doc":"gleatfy","title":"click_url","content":"pub fn click_url(\n  builder: Builder,\n  is click_url: String,\n) -&gt; Builder\n Set an optional URL to open when the notification is clicked\n See https://docs.ntfy.sh/publish/#click-action\n \nSynonyms:\ngleatfy.click_url\ngleatfy click_url","url":"gleatfy.html#click_url"},{"doc":"gleatfy","title":"delay","content":"pub fn delay(builder: Builder, is delay: String) -&gt; Builder\n Set an optinal delay for notification delivery\n See https://docs.ntfy.sh/publish/#scheduled-delivery\n \nSynonyms:\ngleatfy.delay\ngleatfy delay","url":"gleatfy.html#delay"},{"doc":"gleatfy","title":"email","content":"pub fn email(builder: Builder, to email: String) -&gt; Builder\n Forward the notification to an email address\n See https://docs.ntfy.sh/publish/#e-mail-notifications\n \nSynonyms:\ngleatfy.email\ngleatfy email","url":"gleatfy.html#email"},{"doc":"gleatfy","title":"icon_url","content":"pub fn icon_url(builder: Builder, is icon_url: String) -&gt; Builder\n Set a notification icon by URL\n https://docs.ntfy.sh/publish/#icons\n \nSynonyms:\ngleatfy.icon_url\ngleatfy icon_url","url":"gleatfy.html#icon_url"},{"doc":"gleatfy","title":"login","content":"pub fn login(builder: Builder, with login: Login) -&gt; Builder\n Set the authentication method and data. Defaults to no authentication\n See https://docs.ntfy.sh/publish/#authentication\n \nSynonyms:\ngleatfy.login\ngleatfy login","url":"gleatfy.html#login"},{"doc":"gleatfy","title":"message","content":"pub fn message(builder: Builder, is message: Message) -&gt; Builder\n Set the notification&#39;s message body.\n \n ## Examples\n \n \n new() |&gt; message(Text(&quot;Plain text&quot;))\n \n \n \n new() |&gt; message(Markdown(&quot;**Markdown** text&quot;))\n \n \n For markdown messages see https://docs.ntfy.sh/publish/#markdown-formatting\n \nSynonyms:\ngleatfy.message\ngleatfy message","url":"gleatfy.html#message"},{"doc":"gleatfy","title":"new","content":"pub fn new() -&gt; Builder\n Creates a fresh notification message builder\n \nSynonyms:\ngleatfy.new\ngleatfy new","url":"gleatfy.html#new"},{"doc":"gleatfy","title":"priority","content":"pub fn priority(\n  builder: Builder,\n  is priority: Priority,\n) -&gt; Builder\n Set the notification&#39;s priority\n See https://docs.ntfy.sh/publish/#message-priority\n \nSynonyms:\ngleatfy.priority\ngleatfy priority","url":"gleatfy.html#priority"},{"doc":"gleatfy","title":"send","content":"pub fn send(\n  builder: Builder,\n  using send_fn: fn(Request(String)) -&gt;\n    Result(Response(String), a),\n) -&gt; Result(String, Error(a))\n Create the HTTP request, hands it over to `send_fn` and decodes its return value\n \n ## Example\n \n \n new() |&gt; topic(&quot;alert&quot;) |&gt; send(https.send)\n /// -&gt; Ok(&quot;message-id&quot;)\n \n \nSynonyms:\ngleatfy.send\ngleatfy send","url":"gleatfy.html#send"},{"doc":"gleatfy","title":"server","content":"pub fn server(builder: Builder, is server: String) -&gt; Builder\n Set the ntfy instance to use. Defaults to https://ntfy.sh\n \nSynonyms:\ngleatfy.server\ngleatfy server","url":"gleatfy.html#server"},{"doc":"gleatfy","title":"tags","content":"pub fn tags(builder: Builder, are tags: List(String)) -&gt; Builder\n Set optional tags for the notification\n See https://docs.ntfy.sh/publish/#tags-emojis\n \nSynonyms:\ngleatfy.tags\ngleatfy tags","url":"gleatfy.html#tags"},{"doc":"gleatfy","title":"title","content":"pub fn title(builder: Builder, is title: String) -&gt; Builder\n Set the notification&#39;s title.\n See https://docs.ntfy.sh/publish/#message-title\n \nSynonyms:\ngleatfy.title\ngleatfy title","url":"gleatfy.html#title"},{"doc":"gleatfy","title":"topic","content":"pub fn topic(builder: Builder, is topic: String) -&gt; Builder\n Set the **mandatory** topic to send the notification to.\n \nSynonyms:\ngleatfy.topic\ngleatfy topic","url":"gleatfy.html#topic"},{"doc":"gleatfy","title":"without_firebase","content":"pub fn without_firebase(builder: Builder) -&gt; Builder\n Tell the server not to send this notification to FCM\n See https://docs.ntfy.sh/publish/#disable-firebase\n \nSynonyms:\ngleatfy.without_firebase\ngleatfy without_firebase","url":"gleatfy.html#without_firebase"},{"doc":"gleatfy","title":"without_message_cache","content":"pub fn without_message_cache(builder: Builder) -&gt; Builder\n Tell the server not to cache this notification\n See https://docs.ntfy.sh/publish/#message-caching\n \nSynonyms:\ngleatfy.without_message_cache\ngleatfy without_message_cache","url":"gleatfy.html#without_message_cache"},{"doc":"gleatfy","title":"gleatfy","content":"","url":"gleatfy.html"}]);